==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/knewstuff/knewstuff.cpp <==
/*
    This file is part of KNewStuff.
    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include <kaction.h>
#include <kapplication.h>
#include <krandom.h>
#include <kdebug.h>
#include <kicon.h>
#include <klocale.h>
#include <kstandarddirs.h>

#include "engine.h"

#include "knewstuff.h"

using namespace KNS;

KAction* KNS::standardAction(const QString& what,
                             const QObject *recvr,
                             const char *slot, KActionCollection* parent,
                             const char *name)
{
  KAction *action = new KAction( i18n("Download New %1", what), parent, name );
  action->setIcon( KIcon( "knewstuff" ) );
  QObject::connect( action, SIGNAL( triggered( bool ) ), recvr, slot );

  return action;
}

KNewStuff::KNewStuff( const QString &type, QWidget *parentWidget )
{
  mEngine = new Engine( this, type, parentWidget );
}

KNewStuff::KNewStuff( const QString &type, const QString &providerList, QWidget *parentWidget )
{
  mEngine = new Engine( this, type, providerList, parentWidget );
}

QString KNewStuff::type() const
{
  return mEngine->category();
}

QWidget *KNewStuff::parentWidget() const
{
  return mEngine->parentWidget();
}

KNewStuff::~KNewStuff()
{
  delete mEngine;
}

void KNewStuff::download()
{
  mEngine->download();
}

QString KNewStuff::downloadDestination( Entry * )
{
  return KGlobal::dirs()->saveLocation( "tmp" ) +
         KRandom::randomString( 10 );
}

void KNewStuff::upload()
{
  mEngine->upload();
}

void KNewStuff::upload( const QString &fileName, const QString previewName )
{
  mEngine->upload(fileName, previewName);
}

==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/knewstuff/knewstuff.cpp <==
/*
    This file is part of KNewStuff.
    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include <kaction.h>
#include <kapplication.h>
#include <krandom.h>
#include <kdebug.h>
#include <kicon.h>
#include <klocale.h>
#include <kstandarddirs.h>
#include <kactioncollection.h>

#include "engine.h"

#include "knewstuff.h"

using namespace KNS;

KAction* KNS::standardAction(const QString& what,
                             const QObject *recvr,
                             const char *slot, KActionCollection* parent,
                             const char *name)
{
  KAction *action = new KAction( i18n("Download New %1", what), parent );
  parent->addAction(name, action);
  action->setIcon( KIcon( "knewstuff" ) );
  QObject::connect( action, SIGNAL( triggered( bool ) ), recvr, slot );

  return action;
}

KNewStuff::KNewStuff( const QString &type, QWidget *parentWidget )
{
  mEngine = new Engine( this, type, parentWidget );
}

KNewStuff::KNewStuff( const QString &type, const QString &providerList, QWidget *parentWidget )
{
  mEngine = new Engine( this, type, providerList, parentWidget );
}

QString KNewStuff::type() const
{
  return mEngine->category();
}

QWidget *KNewStuff::parentWidget() const
{
  return mEngine->parentWidget();
}

KNewStuff::~KNewStuff()
{
  delete mEngine;
}

void KNewStuff::download()
{
  mEngine->download();
}

QString KNewStuff::downloadDestination( Entry * )
{
  return KGlobal::dirs()->saveLocation( "tmp" ) +
         KRandom::randomString( 10 );
}

void KNewStuff::upload()
{
  mEngine->upload();
}

void KNewStuff::upload( const QString &fileName, const QString previewName )
{
  mEngine->upload(fileName, previewName);
}
